@@ -20,7 +20,7 @@
 
 use 5.014_001;
 
-package Term::CLI::Command::Help  0.04006 {
+package Term::CLI::Command::Help  0.04007 {
 
 use Modern::Perl 1.20140107;
 use Pod::Text::Termcap 2.08;
@@ -301,7 +301,7 @@ sub _execute_help {
             return %args;
         }
 
-        local( $::SIG{PIPE} ) = 'IGNORE'; # Temporarily avoid accidents.
+        local( $SIG{PIPE} ) = 'IGNORE'; # Temporarily avoid accidents.
         print $pager_fh $args{text};
 
         $pager_fh->close;
@@ -337,7 +337,7 @@ Term::CLI::Command::Help - A generic 'help' command for Term::CLI
 
 =head1 VERSION
 
-version 0.04006
+version 0.04007
 
 =head1 SYNOPSIS
 
